searchData={"content_type":"text/markdown","items":[{"doc":"A lightweight image processing module in Elixir using CImg, aimed at creating auxiliary routines for Deep Learning.\r\n\r\n#","ref":"CImg.html","title":"CImg","type":"module"},{"doc":"Each function provided by CImg can be used alone (eager execution) or\r\nas a set of functions (session execution).\r\n\r\nEAGER execution is good for interactive work because you can see the results\r\nof your image processing immediately. But it tends to consume more memory\r\nthan necessary. On the other hand, SESSION execution reduces memory consumption\r\nbecause after assembling the image processing sequence, it is executed all at once.\r\n\r\nTo perform image processing in SESSION mode, you must assemble a image processing\r\nsequence using Elixir's pipe syntax. At the entrance of the pipe, place\r\na function {seed} that generates a %Builder{}, then pipe in the necessary\r\nimage processing {grow}, and finally place a function {crop} that executes\r\nthose image processing.\r\n\r\nIn this document, the following symbols indicate which category each function belongs to.\r\n  * {seed} - generate %Builder{}\r\n  * {grow} - image processing piece\r\n  * {crop} - execute session and get result\r\n\r\n##","ref":"CImg.html#module-session-execution","title":"Session execution - CImg","type":"module"},{"doc":"```elixir\r\n  img = CImg.load(\"sample.jpg\")\r\n\r\n  CImg.builder(img)               # generate %Builder{} with %CImg{} as seed image\r\n  |> CImg.draw_circle(100, 100, 30, {0,0,255}) # building an image processing session\r\n  |> CImg.draw_circle(150, 200, 40, {255,0,0}) # ...\r\n  |> CImg.display(disp)           # execute above session and display result image on PC screen\r\n  ```\r\n\r\n#","ref":"CImg.html#module-examples","title":"Examples - CImg","type":"module"},{"doc":"It is easy to exchange %CImg{} and Nx tensors.\r\n\r\n```elixir\r\n# convert CImg image to Nx.Tensor\r\niex> img0 = CImg.load(\"sample.jpg\")\r\n%CImg{{2448, 3264, 1, 3}, handle: #Reference }\r\niex> tensor = CImg.to_binary(img0, dtype: \"  Nx.from_binary({:u, 8})\r\n\r\n# convert Nx.Tensor to CImg image\r\niex> img1 = Nx.to_binary(tensor)\r\n       |>CImg.from_bin(2448, 3264, 1, 3, \"<u8\")\r\n```","ref":"CImg.html#module-data-exchange-with-nx","title":"Data exchange with Nx - CImg","type":"module"},{"doc":"{grow} Append image.","ref":"CImg.html#append/4","title":"CImg.append/4","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * img2 - %CImg{}, append image\r\n  * axis - append on axis: {:x, :y, :z, :c}\r\n  * align -","ref":"CImg.html#append/4-parameters","title":"Parameters - CImg.append/4","type":"function"},{"doc":"```elixir\r\n  img = CImg.load(\"sample.jpg\")\r\n  twice = CImg.append(img, img, :x)\r\n  ```","ref":"CImg.html#append/4-examples","title":"Examples - CImg.append/4","type":"function"},{"doc":"{grow} Blending two images.","ref":"CImg.html#blend/3","title":"CImg.blend/3","type":"function"},{"doc":"* img - %CImg{} or %Builder{} object.\r\n  * mask - %CImg{} object.\r\n  * ratio - blending ratio: (1.0-ratio)*img + ratio*mask","ref":"CImg.html#blend/3-parameters","title":"Parameters - CImg.blend/3","type":"function"},{"doc":"```Elixir\r\n  img = CImg.blend(img_org, img_mask, 0.6)\r\n  ```","ref":"CImg.html#blend/3-examples","title":"Examples - CImg.blend/3","type":"function"},{"doc":"{grow} Bluring image.","ref":"CImg.html#blur/4","title":"CImg.blur/4","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * sigma -\r\n  * boundary_conditions -\r\n  * is_gaussian -","ref":"CImg.html#blur/4-parameters","title":"Parameters - CImg.blur/4","type":"function"},{"doc":"```elixir\r\n  img = CImg.load(\"sample.jpg\")\r\n  blured = CImg.blur(img, 0.3)\r\n  ```","ref":"CImg.html#blur/4-examples","title":"Examples - CImg.blur/4","type":"function"},{"doc":"{seed} Returns an empty builder for recording image processing scripts.","ref":"CImg.html#builder/0","title":"CImg.builder/0","type":"function"},{"doc":"None.","ref":"CImg.html#builder/0-parameters","title":"Parameters - CImg.builder/0","type":"function"},{"doc":"```elixir\r\n  # build a script\r\n  script = CImg.builder()\r\n    |> CImg.gray()\r\n    |> CImg.resize({256, 256})\r\n\r\n  # apply the script to an image.\r\n  seed   = CImg.load(\"sample.jpg\")\r\n  result = CImg.run(script, seed)\r\n  ```","ref":"CImg.html#builder/0-examples","title":"Examples - CImg.builder/0","type":"function"},{"doc":"{seed} Returns a builder with an existing %CImg{} as the seed image.","ref":"CImg.html#builder/1","title":"CImg.builder/1","type":"function"},{"doc":"* img - %CImg{}","ref":"CImg.html#builder/1-parameters","title":"Parameters - CImg.builder/1","type":"function"},{"doc":"```elixir\r\n  cimg = CImg.load(\"sample.jpg\")\r\n\r\n  result = CImg.builder(cimg)  # create %Builder{} has cimg\r\n    |> CImg.draw_circle(100, 100, 30, {0, 255, 0})\r\n    |> CImg.run()\r\n  ```","ref":"CImg.html#builder/1-examples","title":"Examples - CImg.builder/1","type":"function"},{"doc":"{seed} Returns a builder that uses an image read from the file as the seed image.","ref":"CImg.html#builder/2","title":"CImg.builder/2","type":"function"},{"doc":"* atom - image file format: `:jpeg` or `:png`\r\n  * fname - file name","ref":"CImg.html#builder/2-parameters","title":"Parameters - CImg.builder/2","type":"function"},{"doc":"```elixir\r\n  result = CImg.builder(:jpeg, \"sample.jpg\")\r\n    |> CImg.draw_circle(100, 100, 30, {0, 255, 0})\r\n    |> CImg.run()\r\n  ```","ref":"CImg.html#builder/2-examples","title":"Examples - CImg.builder/2","type":"function"},{"doc":"{seed} Returns a builder whose seed image is an image of shape [x,y,z,c] filled with the value `val`.","ref":"CImg.html#builder/5","title":"CImg.builder/5","type":"function"},{"doc":"* x,y,z,c - shape of image\r\n  * val - filling value","ref":"CImg.html#builder/5-parameters","title":"Parameters - CImg.builder/5","type":"function"},{"doc":"```elixir\r\n  res = CImg.builder(640, 480, 1, 3, 64)\r\n    |> CImg.draw_circle(100, 100, 30, {0, 255, 0})\r\n    |> CImg.run()\r\n  ```","ref":"CImg.html#builder/5-examples","title":"Examples - CImg.builder/5","type":"function"},{"doc":"{seed} Returns a builder that takes as seed image a binary - shape[], dtype -\r\nconverted to an image","ref":"CImg.html#builder/6","title":"CImg.builder/6","type":"function"},{"doc":"* bin - binary\r\n  * x,y,z,c - shape of the image represented by `bin`\r\n  * opts - convertion options\r\n    - { :dtype, xxx } - convert data type to pixel.\r\n        available: \"  RGB.","ref":"CImg.html#builder/6-parameters","title":"Parameters - CImg.builder/6","type":"function"},{"doc":"```elixir\r\n  result = CImg.builder(bin 640, 480, 1, 3, dtype: \"  CImg.draw_circle(100, 100, 30, {0, 255, 0})\r\n    |> CImg.run()\r\n  ```","ref":"CImg.html#builder/6-examples","title":"Examples - CImg.builder/6","type":"function"},{"doc":"{grow} Booking to clear the image.","ref":"CImg.html#clear/1","title":"CImg.clear/1","type":"function"},{"doc":"* builder - %Builder{}.","ref":"CImg.html#clear/1-parameters","title":"Parameters - CImg.clear/1","type":"function"},{"doc":"```elixir\r\nresult = CImg.builder(:file, \"sample.jpg\")\r\n  |> CImg.clear()\r\n  |> CImg.run()\r\n```","ref":"CImg.html#clear/1-examples","title":"Examples - CImg.clear/1","type":"function"},{"doc":"{grow} Create color mapped image by lut.","ref":"CImg.html#color_mapping/3","title":"CImg.color_mapping/3","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * lut - color map. build-in or user defined.\r\n    - build-in map: {:default, :lines, :hot, :cool, :jet}\r\n    - user defined: list of color tupple, [{0,0,0},{10,8,9},{22,15,24}...].\r\n  * boundary - handling the pixel value outside the color map range.\r\n    - 0 - set to zero value.\r\n    - 1 -\r\n    - 2 - repeat from the beginning of the color map.\r\n    - 3 - repeat while wrapping the color map.","ref":"CImg.html#color_mapping/3-parameters","title":"Parameters - CImg.color_mapping/3","type":"function"},{"doc":"```elixir\r\n  gray = CImg.load(\"sample.jpg\") |> CImg.gray()\r\n\r\n  jet = CImg.color_mapping(gray, :jet)\r\n  # heat-map coloring.\r\n\r\n  custom = CImg.color_mapping(gray, [{0,0,0},{10,8,9},{22,15,24}], 2)\r\n  # custom coloring.\r\n  ```","ref":"CImg.html#color_mapping/3-examples","title":"Examples - CImg.color_mapping/3","type":"function"},{"doc":"Create image{x,y,z,c} filled `val`.","ref":"CImg.html#create/5","title":"CImg.create/5","type":"function"},{"doc":"* x,y,z,c - image's x-size, y-size, z-size and spectrum.\r\n  * val     - filling value.","ref":"CImg.html#create/5-parameters","title":"Parameters - CImg.create/5","type":"function"},{"doc":"```elixir\r\n  img = CImg.create(200, 100, 1, 3, 127)\r\n  ```","ref":"CImg.html#create/5-examples","title":"Examples - CImg.create/5","type":"function"},{"doc":"{crop} Display the image on the CImgDisplay object.","ref":"CImg.html#display/1","title":"CImg.display/1","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * display - CImgDisplay object","ref":"CImg.html#display/1-parameters","title":"Parameters - CImg.display/1","type":"function"},{"doc":"```elixir\r\n  CImg.display(cimg)\r\n\r\n  CImg.builder(cimg)\r\n  |> CImg.draw_circle(100, 100, 50, {255, 0, 0})\r\n  |> CImg.display()\r\n  ```","ref":"CImg.html#display/1-examples","title":"Examples - CImg.display/1","type":"function"},{"doc":"{crop} Display the image on the CImgDisplay object.","ref":"CImg.html#display/2","title":"CImg.display/2","type":"function"},{"doc":"* cimg - %CImg{} or %Builder{}\r\n  * display - CImgDisplay object","ref":"CImg.html#display/2-parameters","title":"Parameters - CImg.display/2","type":"function"},{"doc":"```elixir\r\n  disp = CImgDisplay.create(img, \"Sample\")\r\n  CImg.display(img, disp)\r\n  ```","ref":"CImg.html#display/2-examples","title":"Examples - CImg.display/2","type":"function"},{"doc":"{crop} Display the image on the Livebook.","ref":"CImg.html#display_kino/2","title":"CImg.display_kino/2","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * mime_type - image file format: `:jpeg`, `:png`","ref":"CImg.html#display_kino/2-parameters","title":"Parameters - CImg.display_kino/2","type":"function"},{"doc":"```elixir\r\n  CImg.builder(:file, \"sample.jpg\")\r\n  |> CImg.display_kino(:jpeg)\r\n  ```","ref":"CImg.html#display_kino/2-examples","title":"Examples - CImg.display_kino/2","type":"function"},{"doc":"{grow} Booking to draw filled circle in the image.","ref":"CImg.html#draw_circle/6","title":"CImg.draw_circle/6","type":"function"},{"doc":"* builder - %Builder{}\r\n  * x0,y0 - circle center location\r\n  * radius - circle radius\r\n  * color - filling color\r\n  * opacity - opacity: 0.0-1.0","ref":"CImg.html#draw_circle/6-parameters","title":"Parameters - CImg.draw_circle/6","type":"function"},{"doc":"```elixir\r\n  result = CImg.builder(cimg)\r\n    |> CImg.draw_circle(imge, 100, 80, 40, {0, 0, 255})\r\n    |> CImg.run()\r\n  ```","ref":"CImg.html#draw_circle/6-examples","title":"Examples - CImg.draw_circle/6","type":"function"},{"doc":"{grow} Booking to draw circle in the image.","ref":"CImg.html#draw_circle/7","title":"CImg.draw_circle/7","type":"function"},{"doc":"* builder - %Builder{}\r\n  * x0,y0 - circle center location\r\n  * radius - circle radius\r\n  * color - boundary color\r\n  * opacity - opacity: 0.0-1.0\r\n  * pattern - boundary line pattern","ref":"CImg.html#draw_circle/7-parameters","title":"Parameters - CImg.draw_circle/7","type":"function"},{"doc":"```Elixir\r\n  result = CImg.builder(cimg)\r\n    |> CImg.draw_circle(imge, 100, 80, 40, {0, 0, 255}, 0.3, 0xFFFFFFFF)\r\n    |> CImg.run()\r\n  ```","ref":"CImg.html#draw_circle/7-examples","title":"Examples - CImg.draw_circle/7","type":"function"},{"doc":"{grow} Booking to draw graph.","ref":"CImg.html#draw_graph/9","title":"CImg.draw_graph/9","type":"function"},{"doc":"* builder - %Builder{}\r\n  * data - plot data (%CImg{})\r\n  * color - RGB color tuple: {R,G,B} where 0 竕ｦ R,G,B 竕ｦ 255\r\n  * opacity -\r\n  * plot_type -\r\n    * 0 = No plot.\r\n    * 1 = Plot using segments.\r\n    * 2 = Plot using cubic splines.\r\n    * 3 = Plot with bars.\r\n  * vertex_type -\r\n    * 0 = No points.\r\n    * 1 = Point.\r\n    * 2 = Straight cross.\r\n    * 3 = Diagonal cross.\r\n    * 4 = Filled circle.\r\n    * 5 = Outlined circle.\r\n    * 6 = Square.\r\n    * 7 = Diamond.\r\n  * ymin, ymax - lower and upper bound of the y-range\r\n  * pattern - line style","ref":"CImg.html#draw_graph/9-parameters","title":"Parameters - CImg.draw_graph/9","type":"function"},{"doc":"```elixir\r\n    CImg.builder(screen)\r\n      |> CImg.draw_graph(CImg.get_crop(image, 0, y, 0, 0, width-1, y, 0, 0), red,   1.0, 1, 0, 255.0, 0.0)\r\n      |> CImg.draw_graph(CImg.get_crop(image, 0, y, 0, 1, width-1, y, 0, 1), green, 1.0, 1, 0, 255.0, 0.0)\r\n      |> CImg.draw_graph(CImg.get_crop(image, 0, y, 0, 2, width-1, y, 0, 2), blue,  1.0, 1, 0, 255.0, 0.0)\r\n      |> CImg.display(draw_disp)\r\n  ```","ref":"CImg.html#draw_graph/9-examples","title":"Examples - CImg.draw_graph/9","type":"function"},{"doc":"[grow] Booking to draw line in the image.","ref":"CImg.html#draw_line/7","title":"CImg.draw_line/7","type":"function"},{"doc":"* builder - %Builder{}\r\n  * x1,y1,x2,y2 - ends of the line. if all of them are integer, they mean\r\n  actual coodinates. if all of them are float, they mean ratio of the image.\r\n  * color - line color\r\n  * opts\r\n    * thick: val - thick of line\r\n    * opacity: val - opacity: 0.0-1.0\r\n    * pattern: val - boundary line pattern: 32bit pattern","ref":"CImg.html#draw_line/7-parameters","title":"Parameters - CImg.draw_line/7","type":"function"},{"doc":"```\r\n  CImg.builder(img)\r\n  |> CImg.draw_line(10, 10, 20, 30, :white, thick: 3)\r\n  ```","ref":"CImg.html#draw_line/7-examples","title":"Examples - CImg.draw_line/7","type":"function"},{"doc":"[grow] Booking to draw marker.","ref":"CImg.html#draw_marker/5","title":"CImg.draw_marker/5","type":"function"},{"doc":"* builder - %Builder{}\r\n  * x,y - location. if all of them are integer, they mean\r\n  actual coodinates. if all of them are float, they mean ratio of the image.\r\n  * color - marker color\r\n  * opts\r\n    * size - size of marker (>= 0)\r\n    * mark - shape of marker (only :circle is avalable now)","ref":"CImg.html#draw_marker/5-parameters","title":"Parameters - CImg.draw_marker/5","type":"function"},{"doc":"{grow} Booking to move pixels on the image according to the mapping table.","ref":"CImg.html#draw_morph/5","title":"CImg.draw_morph/5","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * mapping - mapping table. ex) [{[10,10],[10,20]}], move pixel at [10,10] to [10,20]\r\n  * cx, cy, cz - location of upper-left mapping table on both images.","ref":"CImg.html#draw_morph/5-parameters","title":"Parameters - CImg.draw_morph/5","type":"function"},{"doc":"```elixir\r\n  map = [{[20,20],[25,25]}, {[20,21],[25,26]}]\r\n\r\n  result = CImg.builder(:jpeg, \"sample.jpg\")\r\n    |> CImg.draw_morph(map)\r\n    |> CImg.run()\r\n  ```","ref":"CImg.html#draw_morph/5-examples","title":"Examples - CImg.draw_morph/5","type":"function"},{"doc":"{grow} Booking to draw rectangle in the image.","ref":"CImg.html#draw_rect/8","title":"CImg.draw_rect/8","type":"function"},{"doc":"* builder - %Builder{}\r\n  * x0,y0,x1,y1 - diagonal coordinates. if all of them are integer, they mean\r\n  actual coodinates. if all of them are float within 0.0-1.0, they mean ratio\r\n  of the image.\r\n  * color - boundary color\r\n  * opacity - opacity: 0.0-1.0\r\n  * pattern - boundary line pattern: 32bit pattern","ref":"CImg.html#draw_rect/8-parameters","title":"Parameters - CImg.draw_rect/8","type":"function"},{"doc":"```elixir\r\n  CImg.builder(cimg)\r\n  |> CImg.draw_rect(img, 50, 30, 100, 80, {255, 0, 0}, 0.3, 0xFF00FF00)\r\n  |> CImg.display()\r\n\r\n  CImg.builder(cimg)\r\n  |> CImg.draw_rect(img, 0.2, 0.3, 0.6, 0.8, {0, 255, 0})\r\n  |> CImg.display()\r\n  ```","ref":"CImg.html#draw_rect/8-examples","title":"Examples - CImg.draw_rect/8","type":"function"},{"doc":"{grow} Draw text in th image.","ref":"CImg.html#draw_text/8","title":"CImg.draw_text/8","type":"function"},{"doc":"* builder - %Builder{}\r\n  * x,y - position on the image where the text will begin to be drawn.\r\n  * text - the text to be drawn.\r\n  * font_height - font height in pixels.\r\n  * fg_color - foreground color. choose one of the following:\r\n          :white,:sliver,:gray,:black,:red,:maroon,:yellow,:olive,\r\n          :lime,:green,:aqua,:teal,:blue,:navy,:fuchsia,:purple,\r\n          :transparent\r\n  * bg_color - background color.\r\n  * opacity - opacity: 0.0..1.0.","ref":"CImg.html#draw_text/8-parameters","title":"Parameters - CImg.draw_text/8","type":"function"},{"doc":"```elixir\r\n  result = CImg.draw_text(builder, 10, 20, \"Hello world!\", 32, :white)\r\n  ```","ref":"CImg.html#draw_text/8-examples","title":"Examples - CImg.draw_text/8","type":"function"},{"doc":"{grow} Booking to fill the image with `val`.","ref":"CImg.html#fill/2","title":"CImg.fill/2","type":"function"},{"doc":"* builder - %Builder{}\r\n  * val - filling value.","ref":"CImg.html#fill/2-parameters","title":"Parameters - CImg.fill/2","type":"function"},{"doc":"```Elixir\r\n  result = CImg.builder(cimg)\r\n    |> CImg.fill(img, 0x7f)\r\n    |> CImg.run()\r\n  ```","ref":"CImg.html#fill/2-examples","title":"Examples - CImg.fill/2","type":"function"},{"doc":"{grow} Booking to draw filled circle in the image.","ref":"CImg.html#fill_circle/7","title":"CImg.fill_circle/7","type":"function"},{"doc":"* builder - %Builder{}\r\n  * x0,y0 - circle center location\r\n  * radius - circle radius\r\n  * color - filling color\r\n  * opacity - opacity: 0.0-1.0\r\n  * pattern - boundary line pattern","ref":"CImg.html#fill_circle/7-parameters","title":"Parameters - CImg.fill_circle/7","type":"function"},{"doc":"```elixir\r\n  result = CImg.builder(cimg)\r\n    |> CImg.fill_circle(imge, 100, 80, 40, {0, 0, 255}, 0xF0F0F0F0)\r\n    |> CImg.run()\r\n  ```","ref":"CImg.html#fill_circle/7-examples","title":"Examples - CImg.fill_circle/7","type":"function"},{"doc":"{grow} Booking to draw filled rectangle in the image.","ref":"CImg.html#fill_rect/8","title":"CImg.fill_rect/8","type":"function"},{"doc":"* builder - %Builder{}\r\n  * x0,y0,x1,y1 - diagonal coordinates. if all of them are integer, they mean\r\n  actual coodinates. if all of them are float within 0.0-1.0, they mean ratio\r\n  of the image.\r\n  * color - boundary color\r\n  * opacity - opacity: 0.0-1.0","ref":"CImg.html#fill_rect/8-parameters","title":"Parameters - CImg.fill_rect/8","type":"function"},{"doc":"```elixir\r\n  CImg.builder(cimg)\r\n  |> CImg.fill_rect(img, 50, 30, 100, 80, {255, 0, 0}, 0.3)\r\n  |> CImg.display()\r\n\r\n  CImg.builder(cimg)\r\n  |> CImg.fill_rect(img, 0.2, 0.3, 0.6, 0.8, {0, 255, 0})\r\n  |> CImg.display()\r\n  ```","ref":"CImg.html#fill_rect/8-examples","title":"Examples - CImg.fill_rect/8","type":"function"},{"doc":"Create a image from jpeg/png format binary.\r\nYou can create an image from loaded binary of the JPEG/PNG file.","ref":"CImg.html#from_binary/1","title":"CImg.from_binary/1","type":"function"},{"doc":"* jpeg_or_png - loaded binary of the image file.","ref":"CImg.html#from_binary/1-parameters","title":"Parameters - CImg.from_binary/1","type":"function"},{"doc":"```elixir\r\n  bin  = File.read!(\"sample.jpg\")\r\n  jpeg = CImg.from_binary(bin)\r\n  ```","ref":"CImg.html#from_binary/1-examples","title":"Examples - CImg.from_binary/1","type":"function"},{"doc":"Create image{x,y,z,c} from raw binary.\r\n`from_binary` helps you to make the image from the serialiezed output tensor of DNN model.","ref":"CImg.html#from_binary/6","title":"CImg.from_binary/6","type":"function"},{"doc":"* bin - raw binary data to have in a image.\r\n  * x,y,z,c - image's x-size, y-size, z-size and spectrum.\r\n  * opts - convertion options\r\n    - { :dtype, xxx } - convert data type to pixel.\r\n        available: \"  RGB.","ref":"CImg.html#from_binary/6-parameters","title":"Parameters - CImg.from_binary/6","type":"function"},{"doc":"```elixir\r\n  bin = TflInterp.get_output_tensor(__MODULE__, 0)\r\n  img = CImg.from_binary(bin, 300, 300, 1, 3, dtype: \"<f4\")\r\n\r\n  img = CImg.from_binary(bin, 300, 300, 1, 3, gauss: {{103.53,57.375},{116.28,57.12},{123.675,58.395}})\r\n  ```","ref":"CImg.html#from_binary/6-examples","title":"Examples - CImg.from_binary/6","type":"function"},{"doc":"Create the image from %Npy{} format data.","ref":"CImg.html#from_npy/1","title":"CImg.from_npy/1","type":"function"},{"doc":"* npy - %Npy{} has 3 rank.","ref":"CImg.html#from_npy/1-parameters","title":"Parameters - CImg.from_npy/1","type":"function"},{"doc":"```elixir\r\n  {:ok, npy} = Npy.load(\"image.npy\")\r\n  img = CImg.from_npy(npy)\r\n  ```","ref":"CImg.html#from_npy/1-examples","title":"Examples - CImg.from_npy/1","type":"function"},{"doc":"{crop} Get the pixel value at (x, y).","ref":"CImg.html#get/5","title":"CImg.get/5","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * x,y,z,c - location in the image.","ref":"CImg.html#get/5-parameters","title":"Parameters - CImg.get/5","type":"function"},{"doc":"```elixir\r\n  val = CImg.get(img, 120, 40)\r\n  ```","ref":"CImg.html#get/5-examples","title":"Examples - CImg.get/5","type":"function"},{"doc":"{crop} Extracting a partial image specified in a window from an image.","ref":"CImg.html#get_crop/10","title":"CImg.get_crop/10","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * x0,y0,z0,c0, x1,y1,z1,c1 - window\r\n  * bundary_condition -","ref":"CImg.html#get_crop/10-parameters","title":"Parameters - CImg.get_crop/10","type":"function"},{"doc":"```elixir\r\n  partial = CImg.get_crop(img, 100, 100, 0, 0, 400, 600, 0, 3)\r\n  ```","ref":"CImg.html#get_crop/10-examples","title":"Examples - CImg.get_crop/10","type":"function"},{"doc":"{grow} Get the gray image of the image.","ref":"CImg.html#gray/2","title":"CImg.gray/2","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * opt_pn - intensity inversion: 0 (default) - no-inversion, 1 - inversion","ref":"CImg.html#gray/2-parameters","title":"Parameters - CImg.gray/2","type":"function"},{"doc":"```elixir\r\n  gray = CImg.gray(img)\r\n  ```","ref":"CImg.html#gray/2-examples","title":"Examples - CImg.gray/2","type":"function"},{"doc":"{grow} Get the inverted image of the image.","ref":"CImg.html#invert/1","title":"CImg.invert/1","type":"function"},{"doc":"```elixir\r\n  inv = CImg.invert(img)\r\n  # get inverted image\r\n  ```","ref":"CImg.html#invert/1-examples","title":"Examples - CImg.invert/1","type":"function"},{"doc":"Load a image from file. The file types supported by this function are jpeg, ping and bmp.\r\nThe file extension identifies which file type it is.","ref":"CImg.html#load/1","title":"CImg.load/1","type":"function"},{"doc":"* fname - file path of the image.","ref":"CImg.html#load/1-parameters","title":"Parameters - CImg.load/1","type":"function"},{"doc":"```elixir\r\n  img = CImg.load(\"sample.jpg\")\r\n  ```","ref":"CImg.html#load/1-examples","title":"Examples - CImg.load/1","type":"function"},{"doc":"{grow} mirroring the image on `axis`","ref":"CImg.html#mirror/2","title":"CImg.mirror/2","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * axis - flipping axis: :x, :y","ref":"CImg.html#mirror/2-parameters","title":"Parameters - CImg.mirror/2","type":"function"},{"doc":"```elixir\r\n  mirror = CImg.mirror(img, :y)\r\n  # vertical flipping\r\n  ```","ref":"CImg.html#mirror/2-examples","title":"Examples - CImg.mirror/2","type":"function"},{"doc":"{grow} Paint mask image.","ref":"CImg.html#paint_mask/4","title":"CImg.paint_mask/4","type":"function"},{"doc":"* img - %CImg{} or %Builder{} object.\r\n  * mask - %CImg{} object, binary image.\r\n  * lut - color map.\r\n  * opacity - opacity: (1.0-opacity)*img + opacity*mask","ref":"CImg.html#paint_mask/4-parameters","title":"Parameters - CImg.paint_mask/4","type":"function"},{"doc":"```Elixir\r\n  img = CImg.paint_mask(img_org, img_mask, [{255,0,0}], 0.6)\r\n  ```","ref":"CImg.html#paint_mask/4-examples","title":"Examples - CImg.paint_mask/4","type":"function"},{"doc":"{grow} Get a new image object resized {x, y}.","ref":"CImg.html#resize/4","title":"CImg.resize/4","type":"function"},{"doc":"* cimg - image object.\r\n  * {x, y} - resize width and height or\r\n    scale  - resize scale\r\n    cimg   - get the size from the cimg object\r\n  * align - alignment mode\r\n    - :none - fit resizing\r\n    - :ul - fixed aspect resizing, upper-leftt alignment.\r\n    - :br - fixed aspect resizing, bottom-right alignment.\r\n    - :crop - resizing the center crop to {x, y}.\r\n  * fill - filling value for the margins, when fixed aspect resizing.","ref":"CImg.html#resize/4-parameters","title":"Parameters - CImg.resize/4","type":"function"},{"doc":"```elixir\r\n  img = CImg.load(\"sample.jpg\")\r\n  result = CImg.get_resize(img, {300,300}, :ul)\r\n  ```","ref":"CImg.html#resize/4-examples","title":"Examples - CImg.resize/4","type":"function"},{"doc":"{crop} Returns an image with the script applied to the seed image.","ref":"CImg.html#run/1","title":"CImg.run/1","type":"function"},{"doc":"* builder - %Builder{}","ref":"CImg.html#run/1-parameters","title":"Parameters - CImg.run/1","type":"function"},{"doc":"```elixir\r\n  result = CImg.builder(100, 100, 1, 3, 0)\r\n    |> CImg.draw_circle(100, 100, 30, {0, 255, 0})\r\n    |> CImg.run()\r\n  ```","ref":"CImg.html#run/1-examples","title":"Examples - CImg.run/1","type":"function"},{"doc":"{crop} Returns an image with the script applied to `cimg`.","ref":"CImg.html#run/2","title":"CImg.run/2","type":"function"},{"doc":"* builder - %Builder{}\r\n  * cimg - %CImg{}","ref":"CImg.html#run/2-parameters","title":"Parameters - CImg.run/2","type":"function"},{"doc":"```elixir\r\n  cimg = CImg.load(\"sample.jpg\")\r\n\r\n  result = CImg.builder()\r\n    |> CImg.draw_circle(100, 100, 30, {0, 255, 0})\r\n    |> CImg.runit(cimg)\r\n  ```","ref":"CImg.html#run/2-examples","title":"Examples - CImg.run/2","type":"function"},{"doc":"{crop} Save the image to the file.","ref":"CImg.html#save/2","title":"CImg.save/2","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * fname - file path for the image. (only jpeg images - xxx.jpg - are available now)","ref":"CImg.html#save/2-parameters","title":"Parameters - CImg.save/2","type":"function"},{"doc":"```elixir\r\n  CImg.save(img, \"sample.jpg\")\r\n  ```","ref":"CImg.html#save/2-examples","title":"Examples - CImg.save/2","type":"function"},{"doc":"{grow} Set the pixel value at (x, y).","ref":"CImg.html#set/6","title":"CImg.set/6","type":"function"},{"doc":"* builder - %Builder{}\r\n  * val - value.\r\n  * x,y,z,c - location in the image.","ref":"CImg.html#set/6-parameters","title":"Parameters - CImg.set/6","type":"function"},{"doc":"```elixir\r\n  result = CImg.builder(cimg)\r\n    |> CImg.set(0x7f, 120, 40)\r\n    |> CImg.run()\r\n  ```","ref":"CImg.html#set/6-examples","title":"Examples - CImg.set/6","type":"function"},{"doc":"{crop} Get shape {x,y,z,c} of the image","ref":"CImg.html#shape/1","title":"CImg.shape/1","type":"function"},{"doc":"* img - %CImg{} or %Builder{}","ref":"CImg.html#shape/1-parameters","title":"Parameters - CImg.shape/1","type":"function"},{"doc":"```elixir\r\n  shape = CImg.shape(img)\r\n  ```","ref":"CImg.html#shape/1-examples","title":"Examples - CImg.shape/1","type":"function"},{"doc":"{crop} Get byte size of the image","ref":"CImg.html#size/1","title":"CImg.size/1","type":"function"},{"doc":"* img - %CImg{} or %Builder{}","ref":"CImg.html#size/1-parameters","title":"Parameters - CImg.size/1","type":"function"},{"doc":"```elixir\r\n  size = CImg.size(img)\r\n  ```","ref":"CImg.html#size/1-examples","title":"Examples - CImg.size/1","type":"function"},{"doc":"{grow} Thresholding the image.","ref":"CImg.html#threshold/4","title":"CImg.threshold/4","type":"function"},{"doc":"* img - %CImg{} or %Builder{} object.\r\n  * val - threshold value\r\n  * soft -\r\n  * strict -","ref":"CImg.html#threshold/4-parameters","title":"Parameters - CImg.threshold/4","type":"function"},{"doc":"```Elixir\r\n  res = CImg.threshold(img, 100)\r\n  ```","ref":"CImg.html#threshold/4-examples","title":"Examples - CImg.threshold/4","type":"function"},{"doc":"{crop} Get serialized binary of the image from top-left to bottom-right.\r\n`to_binary/2` helps you to make 32bit-float arrary for the input tensors of DNN model\r\nor jpeg/png format binary on memory.","ref":"CImg.html#to_binary/2","title":"CImg.to_binary/2","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * opts - conversion options\r\n    - :jpeg - convert to JPEG format binary.\r\n    - :png - convert to PNG format binary.\r\n\r\n    following options can be applied when converting the image to row binary.\r\n    - { :dtype, xx } - convert pixel value to data type.\r\n         available: \"  BGR.","ref":"CImg.html#to_binary/2-parameters","title":"Parameters - CImg.to_binary/2","type":"function"},{"doc":"```elixir\r\n  img = CImg.load(\"sample.jpg\")\r\n\r\n  jpeg = CImg.to_binary(img, :jpeg)\r\n  # convert to JPEG format binary on memory.\r\n\r\n  png = CImg.to_binary(img, :png)\r\n  # convert to PNG format binary on memory.\r\n\r\n  bin1 = CImg.to_binary(img, [{dtype: \"<f4\"}, {:range, {-1.0, 1.0}}, :nchw])\r\n  # convert pixel value to 32bit-float in range -1.0..1.0 and transform axis to NCHW.\r\n\r\n  bin2 = CImg.to_binary(img, dtype: \"<f4\")\r\n  # convert pixel value to 32bit-float in range 0.0..1.0.\r\n\r\n  bin3 = CImg.to_binary(img, gauss: {{103.53,57.375},{116.28,57.12},{123.675,58.395}})\r\n  # convert pixel value to 32bit-float normalized by Gaussian destribution: mu-R=103.53, sigma-R=57.375,...\r\n  ```","ref":"CImg.html#to_binary/2-examples","title":"Examples - CImg.to_binary/2","type":"function"},{"doc":"{crop} Convert the image to %Npy{} format data.","ref":"CImg.html#to_npy/2","title":"CImg.to_npy/2","type":"function"},{"doc":"* img - %CImg{} or %Builder{}\r\n  * opts - conversion options\r\n    - { :dtype, xx } - convert pixel value to data type.\r\n         available: \"  BGR.","ref":"CImg.html#to_npy/2-parameters","title":"Parameters - CImg.to_npy/2","type":"function"},{"doc":"```elixir\r\n  img = CImg.load(\"sample.jpg\")\r\n\r\n  npy1 =\r\n    img\r\n    |> CImg.to_npy()\r\n\r\n  npy2 =\r\n    img\r\n    |> CImg.to_npy([{dtype: \"<f4\"}, {:range, {-1.0, 1.0}}, :nchw])\r\n  # convert pixel value to 32bit-float in range -1.0..1.0 and transform axis to NCHW.\r\n  ```","ref":"CImg.html#to_npy/2-examples","title":"Examples - CImg.to_npy/2","type":"function"},{"doc":"{grow} transpose the image","ref":"CImg.html#transpose/1","title":"CImg.transpose/1","type":"function"},{"doc":"* img - %CImg{} or %Builder{}","ref":"CImg.html#transpose/1-parameters","title":"Parameters - CImg.transpose/1","type":"function"},{"doc":"```elixir\r\n  transposed = CImg.transpose(img)\r\n  ```","ref":"CImg.html#transpose/1-examples","title":"Examples - CImg.transpose/1","type":"function"},{"doc":"Record the image processing sequence for SESSION execution.","ref":"CImg.Builder.html","title":"CImg.Builder","type":"module"},{"doc":"CImg utility library.","ref":"CImg.Util.html","title":"CImg.Util","type":"module"},{"doc":"Get aspect of the image.","ref":"CImg.Util.html#aspect/1","title":"CImg.Util.aspect/1","type":"function"},{"doc":"* img - %CImg{}","ref":"CImg.Util.html#aspect/1-parameters","title":"Parameters - CImg.Util.aspect/1","type":"function"},{"doc":"Get inverse aspect of the image.","ref":"CImg.Util.html#inv_aspect/1","title":"CImg.Util.inv_aspect/1","type":"function"},{"doc":"* img - %CImg{}","ref":"CImg.Util.html#inv_aspect/1-parameters","title":"Parameters - CImg.Util.inv_aspect/1","type":"function"},{"doc":"[util] Get a rondom color.","ref":"CImg.Util.html#rand_color/0","title":"CImg.Util.rand_color/0","type":"function"},{"doc":"[util] Make random color palette %{}.","ref":"CImg.Util.html#rand_palette/1","title":"CImg.Util.rand_palette/1","type":"function"},{"doc":"* keys - keys of the color palette\r\n    * if keys is integer -> 0..(keys-1)\r\n    * if keys is binary  -> read from the file \"keys\"\r\n    * if keys is list    -> use it","ref":"CImg.Util.html#rand_palette/1-parameters","title":"Parameters - CImg.Util.rand_palette/1","type":"function"},{"doc":"Display the CImg objects on PC screen. This module also provides the functionality\r\nto handle mouse-event, key-board-event, window-close-event, timer-event etc.\r\n\r\nNote: You can only use these features in :dev or :test mode.","ref":"CImgDisplay.html","title":"CImgDisplay","type":"module"},{"doc":"","ref":"CImgDisplay.html#button/1","title":"CImgDisplay.button/1","type":"function"},{"doc":"Create display object.","ref":"CImgDisplay.html#create/5","title":"CImgDisplay.create/5","type":"function"},{"doc":"","ref":"CImgDisplay.html#create/5-parameters","title":"Parameters - CImgDisplay.create/5","type":"function"},{"doc":"```Elixir\r\n  iex> img = CImg.load(\"sample.jpg\")\r\n  iex> display = CImgDisplay(img, \"Sample image\")\r\n  iex> \r\n  ```","ref":"CImgDisplay.html#create/5-examples","title":"Examples - CImgDisplay.create/5","type":"function"},{"doc":"","ref":"CImgDisplay.html#is_closed/1","title":"CImgDisplay.is_closed/1","type":"function"},{"doc":"","ref":"CImgDisplay.html#mouse_y/1","title":"CImgDisplay.mouse_y/1","type":"function"},{"doc":"","ref":"CImgDisplay.html#wait/1","title":"CImgDisplay.wait/1","type":"function"},{"doc":"","ref":"CImgDisplay.html#wait/2","title":"CImgDisplay.wait/2","type":"function"},{"doc":"# cimg_ex\r\nA lightweight image processing module in Elixir using CImg, aimed at creating auxiliary routines for Deep Learning.\r\n\r\nNote: Only a few image processing functions are available yet.","ref":"readme.html","title":"cimg_ex","type":"extras"},{"doc":"Image data handled by CImg is placed on the NIF side. On the Elixir side, image processing is performed through\r\n`RESOURCE` of images - generated by NIF - stored in the %CImg{} structure. You cannot directly read or process pixels\r\nin an image. Instead, you must use the image processing functions provided by the CImg module.\r\n\r\nImages are automatically subject to garbage collection when they are no longer used. The NIFs `RESOURCE` management\r\nmechanism is used to achieve this functionality.\r\n\r\nEach function provided by CImg can be used alone or as a set of functions. In the latter case, a seed image is first\r\nprepared using `CImg.builder/1` or similar, and then a series of functions are put together using Elixir's pipe syntax.","ref":"readme.html#design-detail","title":"Design detail - cimg_ex","type":"extras"},{"doc":"I have confirmed it works in the following OS environment.\r\n\r\n- Windows MSYS2/MinGW64\r\n- WSL2/Ubuntu 20.04, 18.04\r\n- Linux Mint 20 \"Ulyana\"\r\n- Nerves rpi","ref":"readme.html#platform","title":"Platform - cimg_ex","type":"extras"},{"doc":"python3 is required to build this module.\r\n\r\nIn addition, the following libraries are required to display images on a PC screen.\r\n\r\n- GDI32 on Windows\r\n- X11 on Linux","ref":"readme.html#requirements","title":"Requirements - cimg_ex","type":"extras"},{"doc":"Add following dependency to your `mix.exs`.\r\n\r\n```elixir\r\ndef deps do\r\n  [\r\n    {:cimg, \"~> 0.1.19\"}\r\n  ]\r\nend\r\n```\r\n\r\nand install dependencies:\r\n\r\n```shell\r\n$ mix deps.get\r\n$ mix deps.compile\r\n```","ref":"readme.html#installation","title":"Installation - cimg_ex","type":"extras"},{"doc":"A sample program is in the demo directory. You can run it by following the steps below.\r\n\r\n```shell\r\n$ cd demo\r\n$ mix deps.get\r\n$ mix run -e \"CImgDemo.demo1\"\r\n```\r\n\r\nClosing the application window will stop the demo program.\r\n\r\nAnother demo:\r\n\r\n```shell\r\n$ mix run -e \"CImgDemo.demo2\"\r\n```\r\n\r\n```shell\r\n$ mix run -e \"CImgDemo.demo3\"\r\n```","ref":"readme.html#demo","title":"Demo - cimg_ex","type":"extras"},{"doc":"The following code is an excerpt of the inference portion from the DeepLab app implemented using TflInterp. \r\nCImg preprocesses the input image and passes it through the DeepLab model.\r\nAnd then, the tensor output by DeepLab is transformed by CImg into a colormaedp image.\r\n\r\n```elixir\r\ndefmodule TflDemo.DeepLab3 do\r\n  alias TflDemo.DeepLab3.Prediction\r\n\r\n  def apply_deeplab3(img_file) do\r\n    img = CImg.load(img_file)\r\n\r\n    segments = Prediction.apply(img)\r\n  end\r\nend\r\n\r\n\r\ndefmodule TflDemo.DeepLab3.Prediction do\r\n  use TflInterp, model: \"priv/lite-model_deeplabv3_1_metadata_2.tflite\"\r\n  \r\n  @deeplab3_shape {257, 257}\r\n\r\n  def apply(img) do\r\n    # preprocess\r\n    bin = img\r\n      |> CImg.resize(@deeplab3_shape)\r\n      |> CImg.to_binary(range: {-1.0, 1.0})\r\n\r\n    # prediction\r\n    outputs =\r\n      __MODULE__\r\n      |> TflInterp.set_input_tensor(0, bin)\r\n      |> TflInterp.invoke()\r\n      |> TflInterp.get_output_tensor(0)\r\n      |> Nx.from_binary({:f, 32}) |> Nx.reshape({257, 257, :auto})\r\n      \r\n    # postprocess\r\n    outputs\r\n    |> Nx.argmax(axis: 2)\r\n    |> Nx.as_type({:u, 8})\r\n    |> Nx.to_binary()\r\n    |> CImg.from_binary(257, 257, 1, 1, \"  CImg.color_mapping(:lines)    # convert into a colormaped image\r\n  end\r\nend\r\n```","ref":"readme.html#example-deep-labelling-for-semantic-image-segmentation","title":"Example: Deep Labelling for Semantic Image Segmentation - cimg_ex","type":"extras"},{"doc":"cimg_ex is licensed under the Apache License Version 2.0.\r\n\r\n#### -- license overview of included 3rd party libraries --\r\n- The \"CImg\" Library is licensed under the CeCILL-C/CeCILL.\r\n- The \"stb\" - single-file public domain libraries for C/C++ - is public domain or MIT licensed.","ref":"readme.html#license","title":"License - cimg_ex","type":"extras"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * added resize function which gets the resizing center crop from a CImg object.","ref":"changelog.html#release-0-1-21","title":"Release 0.1.21 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * added resize function which gets the resizing size from a CImg object.\r\n\r\n  * Bug Fixes and Other Changes\r\n    * revised download method for 3rd-parties.\r\n    * remove python scripts from the publish files.","ref":"changelog.html#release-0-1-20","title":"Release 0.1.20 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * add \"append/4\".","ref":"changelog.html#release-0-1-19","title":"Release 0.1.19 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * add \"paint_mask/4\".","ref":"changelog.html#release-0-1-18","title":"Release 0.1.18 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * add \"draw_marker/5\".","ref":"changelog.html#release-0-1-17","title":"Release 0.1.17 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * support dtype: \"<i4\" in to_binary/2.","ref":"changelog.html#release-0-1-16","title":"Release 0.1.16 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * added \"draw_line\"","ref":"changelog.html#release-0-1-15","title":"Release 0.1.15 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * added \"fill_rect\" and \"fill_circle\".\r\n    * added CImg.Util module including 'aspect' and 'rand_palette'.","ref":"changelog.html#release-0-1-14","title":"Release 0.1.14 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * added Gaussian distribution transformation to `to_binary/e2` and `from_binary/6`.\r\n\r\n  * Bug Fixes and Other Changes\r\n    * fixed a bug of inverse range conversion of from_binary/6.","ref":"changelog.html#release-0-1-13","title":"Release 0.1.13 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * add image blending operation `blend/3`.\r\n\r\n  * Bug Fixes and Other Changes\r\n    * revised `Makefile` for possible to build for Nerves devices on MacOS. (PR#1)","ref":"changelog.html#release-0-1-12","title":"Release 0.1.12 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * add convertion options to `from_binary/6`.\r\n\r\n  * Bug Fixes and Other Changes\r\n    * correct document.","ref":"changelog.html#release-0-1-11","title":"Release 0.1.11 - Changelog","type":"extras"},{"doc":"* Breaking Changes\r\n    * remove deprecated functions. see `Release 0.1.7` changelog.\r\n    * remove Builder.from_binary/1, Builder.resize/4. replaced by session.\r\n\r\n  * Major Features and Improvements\r\n    * add session execution mode.\r\n    * add CImg.display_kino/2.\r\n\r\n  * Bug Fixes and Other Changes\r\n    * fixed a bug that did not release image resources.","ref":"changelog.html#release-0-1-10","title":"Release 0.1.10 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * add draw_text/8.\r\n    * add Builder.from_binary/1, enable Builder.resize/4 (experimental)","ref":"changelog.html#release-0-1-9","title":"Release 0.1.9 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * supported Nerves/rpi.\r\n    * `resize/4` accepts resize scale instead {x, y}.\r\n\r\n  * Bug Fixes and Other Changes\r\n    * corrected argument checking of `color_mapping/2`.\r\n    * replace CImg download script with 'git clone'.","ref":"changelog.html#release-0-1-8","title":"Release 0.1.8 - Changelog","type":"extras"},{"doc":"* Breaking Changes\r\n    * deprecated: `to_jpeg/1`, `to_png/1`, `to_flat/2`. Use `to_binary/2` instead.\r\n    * deprecated: `create_from_bin/6`. Use `from_binary/6` instead.\r\n    * deprecated: `load_from_memory/1`. Use `from_binary/1` instead.\r\n\r\n  * Major Features and Improvements\r\n    * add integrated converter from a image to a binary: `to_binary/2`.\r\n    * add color mapping: `color_mapping/2`.\r\n    * rename `create_from_bin/6` to `from_binary/6`.\r\n    * rename `load_from_memory/1` to `from_binary/1`.\r\n    * `to_npy/2` takes various conversion modes as optional parameters.\r\n\r\n  * Bug Fixes and Other Changes\r\n    * correct an axis order of shape in `from_npy/1`, `to_npy/2`.","ref":"changelog.html#release-0-1-7","title":"Release 0.1.7 - Changelog","type":"extras"},{"doc":"* Major Features and Improvements\r\n    * add image convertor `to_jpeg/1`, `to_png/1` (experimental)","ref":"changelog.html#release-0-1-6-jan-06-2022","title":"Release 0.1.6 (Jan 06 2022) - Changelog","type":"extras"}]}